@@ -6,11 +6,11 @@ from trytond.pool import PoolMeta
 
 from trytond.modules.account_product import MissingFunction
 
-__all__ = ['Category', 'Template']
-__metaclass__ = PoolMeta
+__all__ = ['Category', 'Template', 'Product']
 
 
 class Category:
+    __metaclass__ = PoolMeta
     __name__ = 'product.category'
     account_cogs = fields.Property(fields.Many2One('account.account',
             'Account Cost of Goods Sold', domain=[
@@ -19,15 +19,17 @@ class Category:
                 ],
             states={
                 'invisible': (~Eval('context', {}, ).get('company')
-                    | Eval('account_parent')),
+                    | Eval('account_parent')
+                    | ~Eval('accounting', False)),
                 },
-            depends=['account_parent']))
+            depends=['account_parent', 'accounting']))
     account_cogs_used = MissingFunction(fields.Many2One('account.account',
             'Account Cost of Goods Sold Used'), 'missing_account',
         'get_account')
 
 
 class Template:
+    __metaclass__ = PoolMeta
     __name__ = 'product.template'
     account_cogs = fields.Property(fields.Many2One('account.account',
             'Account Cost of Goods Sold', domain=[
@@ -45,3 +47,12 @@ class Template:
     account_cogs_used = MissingFunction(fields.Many2One('account.account',
             'Account Cost of Goods Sold Used'), 'missing_account',
         'get_account')
+
+
+class Product:
+    __metaclass__ = PoolMeta
+    __name__ = 'product.product'
+    # Avoid raise of UserError from MissingFunction
+    account_cogs_used = fields.Function(
+        fields.Many2One('account.account', 'Account Cost of Goods Sold Used'),
+        'get_template')
