@@ -7,7 +7,6 @@ from trytond.transaction import Transaction
 from trytond import backend
 
 __all__ = ['Move']
-__metaclass__ = PoolMeta
 
 
 def _get_field(type_):
@@ -18,6 +17,7 @@ def _get_field(type_):
 
 
 class Move:
+    __metaclass__ = PoolMeta
     __name__ = 'stock.move'
     in_anglo_saxon_quantity = fields.Float('Input Anglo-Saxon Quantity',
         required=True)
@@ -42,11 +42,11 @@ class Move:
 
     @classmethod
     def __register__(cls, module_name):
-        cursor = Transaction().cursor
+        cursor = Transaction().connection.cursor()
         TableHandler = backend.get('TableHandler')
 
         super(Move, cls).__register__(module_name)
-        table = TableHandler(cursor, cls, module_name)
+        table = TableHandler(cls, module_name)
 
         # Migration from 2.8: split anglo_saxon_quantity
         if table.column_exist('anglo_saxon_quantity'):
